@@ -17,10 +17,10 @@ class ApplicationAdminClass(ApplicationAdmin):
 @admin.register(Scope)
 class ScopeAdminClass(admin.ModelAdmin):
     readonly_fields = ['id']
-    list_display = ['id', 'name', 'key', 'throttling',]
+    list_display = ['id', 'name', 'key',]
 
 
 @admin.register(Throttle)
 class ThrottleAdminClass(admin.ModelAdmin):
     readonly_fields = ['id']
-    list_display = ['id', 'name', 'throttling', ]
+    list_display = ['id', 'name', 'scope', 'rate', ]
